[前][次][番号順一覧][スレッド一覧]

ruby-changes:25472

From: shirosaki <ko1@a...>
Date: Wed, 7 Nov 2012 07:07:45 +0900 (JST)
Subject: [ruby-changes:25472] shirosaki:r37529 (trunk): Fix typos in comments

shirosaki	2012-11-07 07:00:12 +0900 (Wed, 07 Nov 2012)

  New Revision: 37529

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=37529

  Log:
    Fix typos in comments

  Modified files:
    trunk/ChangeLog
    trunk/load.c

Index: ChangeLog
===================================================================
--- ChangeLog	(revision 37528)
+++ ChangeLog	(revision 37529)
@@ -129,7 +129,7 @@
 	* load.c (rb_construct_expanded_load_path): fix for compatibility.
 	  Same checks in rb_get_path_check() are added. We don't replace
 	  $LOAD_PATH and ensure that String object of $LOAD_PATH are frozen.
-	  We don't freeze non String object and expand it every times. We add
+	  We don't freeze non String object and expand it every time. We add
 	  arguments for expanding load path partially and checking if load path
 	  have relative paths or non String objects.
 
@@ -139,7 +139,7 @@
 	* load.c (rb_get_expanded_load_path): fix for rebuilding cache properly.
 	  We check if current working directory is changed and rebuild expanded
 	  load path cache. We expand paths which start with ~ (User HOME) and
-	  non String objects every times for compatibility. We make this
+	  non String objects every time for compatibility. We make this
 	  accessible from other source files.
 
 	* load.c (rb_feature_provided): call rb_get_path() since we changed
Index: load.c
===================================================================
--- load.c	(revision 37528)
+++ load.c	(revision 37529)
@@ -42,7 +42,7 @@
 
 /* Construct expanded load path and store it to cache.
    We rebuild load path partially if the cache is invalid.
-   We don't cache non string object and expand it every times. We ensure that
+   We don't cache non string object and expand it every time. We ensure that
    string objects in $LOAD_PATH are frozen.
  */
 static void
@@ -81,7 +81,7 @@
 	    *has_relative = 1;
 	if (!*has_non_cache && non_cache)
 	    *has_non_cache = 1;
 	/* Freeze only string object. We expand other objects every times. */
 	if (is_string)
 	    rb_str_freeze(path);
 	as_str = rb_get_path_check_convert(path, as_str, level);
@@ -81,7 +81,7 @@
 	if (!*has_non_cache && non_cache)
 	    *has_non_cache = 1;
-	/* Freeze only string object. We expand other objects every times. */
+	/* Freeze only string object. We expand other objects every time. */
 	if (is_string)
 	    rb_str_freeze(path);

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]